@@ -1,6 +1,4 @@
 /*  xfce4-places-plugin
- *
- *  Headers for wrappers to open external applications.
  *
  *  Copyright (c) 2007 Diego Ongaro <ongardie@gmail.com>
  *
@@ -22,15 +20,7 @@
 #ifndef _XFCE_PANEL_PLACES_H
 #define _XFCE_PANEL_PLACES_H
 
-#include <glib.h>
-
 #define PLUGIN_NAME "places"
 
-void places_load_thunar(const gchar *path);
-void places_load_terminal(const gchar *path);
-void places_load_file(const gchar *path);
-void places_gui_exec(const gchar *cmd);
-
-
 #endif
 /* vim: set ai et tabstop=4: */
