@@ -3,6 +3,7 @@
  *  This file handles the GUI. It "owns" the model and cfg.
  *
  *  Copyright (c) 2007-2009 Diego Ongaro <ongardie@gmail.com>
+ *  Copyright (c) 2012 Andrzej <ndrwrdck@gmail.com>
  *
  *  Largely based on:
  *
@@ -13,12 +14,12 @@
  *   - xfdesktop menu plugin
  *     desktop-menu-plugin.c - xfce4-panel plugin that displays the desktop menu
  *     Copyright (C) 2004 Brian Tarricone, <bjt23@cornell.edu>
- *  
+ *
  *   - launcher plugin
  *     launcher.c - (xfce4-panel plugin that opens programs)
  *     Copyright (c) 2005-2007 Jasper Huijsmans <jasper@xfce.org>
  *     Copyright (c) 2006-2007 Nick Schermer <nick@xfce.org>
- * 
+ *
  *  Popup command code adapted from:
  *   - windowlist plugin
  *     windowlist.c - (xfce4-panel plugin that lists open windows)
@@ -46,8 +47,6 @@
 
 #include <gtk/gtk.h>
 
-#define USE_GTK_TOOLTIP_API     GTK_CHECK_VERSION(2,12,0)
-
 #include <libxfce4util/libxfce4util.h>
 #include <libxfce4panel/libxfce4panel.h>
 #include <libxfce4ui/libxfce4ui.h>
@@ -64,46 +63,28 @@
 #include "model_system.h"
 #include "model_volumes.h"
 #include "model_user.h"
-#include "xfce4-popup-places.h"
 #include "button.h"
 
 #ifdef HAVE_LIBNOTIFY
 #include "model_volumes_notify.h"
 #endif
 
-struct _PlacesViewCfgIface
-{
-    PlacesView          *places_view;
-
-    void                (*update_menu)              (PlacesView*);
-    void                (*update_button)            (PlacesView*);
-    void                (*reconfigure_model)        (PlacesView*);
-};
-
 struct _PlacesView
 {
     /* plugin */
     XfcePanelPlugin           *plugin;
-    
+
     /* configuration */
     PlacesCfg                 *cfg;
-    PlacesViewCfgIface        *view_cfg_iface;
-    
+
     /* view */
     GtkWidget                 *button;
     GtkWidget                 *menu;
 
-#if !USE_GTK_TOOLTIP_API
-    GtkTooltips               *tooltips;
-#endif
-
-#if USE_RECENT_DOCUMENTS
     gulong                     recent_manager_changed_handler;
-#endif
-
     gboolean                   needs_separator;
     guint                      menu_timeout_id;
-    
+
     /* model */
     GList                     *bookmark_groups;
 };
@@ -141,26 +122,6 @@ static void     pview_update_menu(PlacesView*);
 static void     pview_destroy_menu(PlacesView*);
 static void     pview_button_update(PlacesView*);
 
-/********** Interface for Cfg's Use **********/
-
-inline void
-places_view_cfg_iface_update_menu(PlacesViewCfgIface *iface)
-{
-    iface->update_menu(iface->places_view);
-}
-
-inline void
-places_view_cfg_iface_update_button(PlacesViewCfgIface *iface)
-{
-    iface->update_button(iface->places_view);
-}
-
-inline void
-places_view_cfg_iface_reconfigure_model(PlacesViewCfgIface *iface)
-{
-    iface->reconfigure_model(iface->places_view);
-}
-
 /********** Model Management **********/
 static void
 pview_destroy_model(PlacesView *view)
@@ -170,7 +131,7 @@ pview_destroy_model(PlacesView *view)
 
     /* we don't want the menu items holding on to any references */
     pview_destroy_menu(view);
-   
+
     if(view->bookmark_groups != NULL){
 
         bookmark_group_li = view->bookmark_groups;
@@ -241,7 +202,7 @@ pview_bookmark_action_call_wrapper(PlacesView *view, PlacesBookmarkAction *actio
             gtk_main_iteration();
 
         places_bookmark_action_call(action);
-    
+
         gtk_widget_set_sensitive(view->button, TRUE);
 
     }else{
@@ -260,14 +221,14 @@ pview_cb_menu_timeout(PlacesView *pd){
     if(!pd->menu_timeout_id)
         goto killtimeout;
 
-    if(pd->menu == NULL || !GTK_WIDGET_VISIBLE(pd->menu))
+    if(pd->menu == NULL || !gtk_widget_is_visible(pd->menu))
         goto killtimeout;
 
     if(pview_model_changed(pd->bookmark_groups))
         pview_open_menu(pd);
 
     PLACES_DEBUG_MENU_TIMEOUT_COUNT(0);
-    return TRUE;   
+    return TRUE;
 
 
   killtimeout:
@@ -281,7 +242,7 @@ pview_cb_menu_timeout(PlacesView *pd){
 
 }
 
-static void 
+static void
 pview_cb_menu_deact(PlacesView *pd, GtkWidget *menu)
 {
     /* deactivate button */
@@ -332,10 +293,60 @@ pview_cb_menu_item_context_act(GtkWidget *item, PlacesView *pd)
 
 }
 
+static void
+pview_cb_menu_context_deact(PlacesView *pd, GtkWidget *context_menu)
+{
+    g_assert(pd != NULL);
+    g_assert(pd->menu != NULL && GTK_IS_WIDGET(pd->menu));
+
+    DBG("Context menu deactivate");
+    gtk_menu_shell_deactivate(GTK_MENU_SHELL(pd->menu));
+}
+
+static void
+open_menu_at_pointer (GtkMenu *menu)
+{
+    GdkDevice    *mouse_device;
+    GdkRectangle  rect;
+    GdkSeat      *seat;
+    GdkWindow    *window;
+    gint          x, y;
+
+    window = gdk_display_get_default_group (gdk_display_get_default ());
+    seat = gdk_display_get_default_seat (gdk_display_get_default ());
+    mouse_device = gdk_seat_get_pointer (seat);
+    gdk_window_get_device_position (window,
+                                    mouse_device,
+                                    &x, &y,
+                                    NULL);
+    rect.x = x;
+    rect.y = y;
+    rect.width = gdk_window_get_width (window);
+    rect.height = gdk_window_get_height (window);
+
+    gtk_menu_popup_at_rect (menu,
+                            window,
+                            &rect,
+                            GDK_GRAVITY_NORTH_WEST,
+                            GDK_GRAVITY_NORTH_WEST,
+                            NULL);
+}
+
+static void
+open_menu_at_widget (GtkMenu   *menu,
+                     GtkWidget *widget)
+{
+    gtk_menu_popup_at_widget (menu,
+                              widget,
+                              GDK_GRAVITY_SOUTH_WEST,
+                              GDK_GRAVITY_NORTH_WEST,
+                              NULL);
+}
+
 static gboolean
 pview_cb_menu_item_do_alt(PlacesView *pd, GtkWidget *menu_item)
 {
-    
+
     PlacesBookmark *bookmark = (PlacesBookmark*) g_object_get_data(G_OBJECT(menu_item), "bookmark");
     GList *actions = bookmark->actions;
     GtkWidget *context, *context_item;
@@ -353,7 +364,7 @@ pview_cb_menu_item_do_alt(PlacesView *pd, GtkWidget *menu_item)
             g_object_set_data(G_OBJECT(context_item), "action", action);
             g_signal_connect(context_item, "activate",
                              G_CALLBACK(pview_cb_menu_item_context_act), pd);
-            
+
             gtk_menu_shell_append(GTK_MENU_SHELL(context), context_item);
             gtk_widget_show(context_item);
 
@@ -361,13 +372,10 @@ pview_cb_menu_item_do_alt(PlacesView *pd, GtkWidget *menu_item)
         }while(actions != NULL);
 
         gtk_widget_show(context);
-        gtk_menu_popup(GTK_MENU(context),
-                       NULL, NULL,
-                       NULL, NULL,
-                       0, gtk_get_current_event_time());
+        open_menu_at_pointer (GTK_MENU (context));
 
         g_signal_connect_swapped(context, "deactivate",
-                                 G_CALLBACK(pview_open_menu), pd);
+                                 G_CALLBACK(pview_cb_menu_context_deact), pd);
 
     }
 
@@ -378,7 +386,7 @@ static gboolean
 pview_cb_menu_item_press(GtkWidget *menu_item, GdkEventButton *event, PlacesView *pd)
 {
 
-    gboolean ctrl =  (event->state & GDK_CONTROL_MASK) && 
+    gboolean ctrl =  (event->state & GDK_CONTROL_MASK) &&
                     !(event->state & (GDK_MOD1_MASK|GDK_SHIFT_MASK|GDK_MOD4_MASK));
     PlacesBookmark *bookmark = (PlacesBookmark*) g_object_get_data(G_OBJECT(menu_item), "bookmark");
 
@@ -398,7 +406,6 @@ pview_cb_menu_item_activate(GtkWidget *menu_item, PlacesView *view)
 
 /* Recent Documents */
 
-#if USE_RECENT_DOCUMENTS
 static void
 pview_cb_recent_item_open(GtkRecentChooser *chooser, PlacesView *pd)
 {
@@ -412,7 +419,7 @@ pview_cb_recent_changed(GtkRecentManager *recent_manager, GtkWidget *recent_menu
 {
     GtkWidget *recent_item;
     int recent_count = 0;
-    
+
     g_object_get(recent_manager,
                  "size", &recent_count,
                  NULL);
@@ -425,8 +432,11 @@ pview_cb_recent_changed(GtkRecentManager *recent_manager, GtkWidget *recent_menu
         gtk_menu_popdown(GTK_MENU(recent_menu));
     }
     else {
-        while (gtk_events_pending())
-            gtk_main_iteration();
+      /* Disabled */
+      /* Causes plugin to crash when search-cmd text field is edited */
+      /* (backspace key is pressed) */
+      /* while (gtk_events_pending())*/
+      /*      gtk_main_iteration();*/
 
         gtk_menu_reposition(GTK_MENU(recent_menu));
     }
@@ -436,12 +446,12 @@ static gboolean
 pview_cb_recent_items_clear(GtkWidget *clear_item, GtkWidget *recent_menu)
 {
     GtkRecentManager *manager = gtk_recent_manager_get_default();
-    
+
     gint removed = gtk_recent_manager_purge_items(manager, NULL);
     DBG("Cleared %d recent items", removed);
 
     pview_cb_recent_changed(manager, recent_menu);
-    
+
     return TRUE;
 }
 
@@ -451,8 +461,6 @@ pview_cb_recent_items_clear3(GtkWidget *clear_item, GdkEventButton *event, GtkWi
     return pview_cb_recent_items_clear(clear_item, recent_menu);
 }
 
-#endif
-
 
 /********** UI Helpers **********/
 
@@ -473,11 +481,11 @@ pview_get_icon(GIcon *icon)
     if (G_IS_THEMED_ICON(icon)) {
         GtkIconInfo *icon_info = gtk_icon_theme_lookup_by_gicon(itheme,
                                                                 icon, size,
-                                                                GTK_ICON_LOOKUP_USE_BUILTIN | GTK_ICON_LOOKUP_GENERIC_FALLBACK | GTK_ICON_LOOKUP_FORCE_SIZE);
+                                                                GTK_ICON_LOOKUP_USE_BUILTIN | GTK_ICON_LOOKUP_FORCE_SIZE);
         if (icon_info) {
             GdkPixbuf *pix_theme = gtk_icon_info_load_icon(icon_info, NULL);
             pix = gdk_pixbuf_copy(pix_theme);
-            gtk_icon_info_free(icon_info);
+            g_object_unref(G_OBJECT(icon_info));
             g_object_unref(G_OBJECT(pix_theme));
         }
     } else if(G_IS_LOADABLE_ICON(icon)) {
@@ -495,20 +503,16 @@ pview_get_icon(GIcon *icon)
 static void
 pview_destroy_menu(PlacesView *view)
 {
-#if USE_RECENT_DOCUMENTS
     GtkRecentManager *recent_manager = gtk_recent_manager_get_default();
-#endif
 
     if(view->menu != NULL) {
         gtk_menu_shell_deactivate(GTK_MENU_SHELL(view->menu));
 
-#if USE_RECENT_DOCUMENTS
         if (view->recent_manager_changed_handler) {
             g_signal_handler_disconnect(recent_manager,
                                         view->recent_manager_changed_handler);
             view->recent_manager_changed_handler = 0;
         }
-#endif
 
         gtk_widget_destroy(view->menu);
         view->menu = NULL;
@@ -537,7 +541,9 @@ pview_add_menu_item(PlacesView *view, PlacesBookmark *bookmark)
         view->needs_separator = FALSE;
     }
 
+    G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     item = gtk_image_menu_item_new_with_label(bookmark->label);
+    G_GNUC_END_IGNORE_DEPRECATIONS
 
     /* try to set icon */
     if(view->cfg->show_icons && bookmark->icon != NULL){
@@ -546,7 +552,9 @@ pview_add_menu_item(PlacesView *view, PlacesBookmark *bookmark)
         if(G_LIKELY(pb != NULL)){
             image = gtk_image_new_from_pixbuf(pb);
             g_object_unref(pb);
+            G_GNUC_BEGIN_IGNORE_DEPRECATIONS
             gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item), image);
+            G_GNUC_END_IGNORE_DEPRECATIONS
         }
     }
 
@@ -587,13 +595,10 @@ pview_update_menu(PlacesView *pd)
     GList *bookmarks;
     PlacesBookmark *bookmark;
     GtkWidget *separator;
-
-#if USE_RECENT_DOCUMENTS
     GtkWidget *recent_menu;
     GtkWidget *clear_item;
     GtkWidget *recent_item;
     GtkRecentManager *recent_manager = gtk_recent_manager_get_default();
-#endif
 
     DBG("destroy menu");
 
@@ -604,7 +609,7 @@ pview_update_menu(PlacesView *pd)
 
     /* Create a new menu */
     pd->menu = gtk_menu_new();
-    
+
     /* make sure the menu popups up in right screen */
     /* need exo_noop for GTK 2.6 and 2.8; starting with 2.10, NULL is OK */
     gtk_menu_attach_to_widget(GTK_MENU(pd->menu), pd->button, (GtkMenuDetachFunc) exo_noop);
@@ -614,7 +619,7 @@ pview_update_menu(PlacesView *pd)
     /* add bookmarks */
     bookmark_group_li = pd->bookmark_groups;
     while(bookmark_group_li != NULL){
-        
+
         if(bookmark_group_li->data == NULL){ /* separator */
 
             pd->needs_separator = TRUE;
@@ -623,7 +628,7 @@ pview_update_menu(PlacesView *pd)
 
             bookmark_group = (PlacesBookmarkGroup*) bookmark_group_li->data;
             bookmarks = places_bookmark_group_get_bookmarks(bookmark_group);
-    
+
             while(bookmarks != NULL){
                 bookmark = (PlacesBookmark*) bookmarks->data;
                 pview_add_menu_item(pd, bookmark);
@@ -638,11 +643,7 @@ pview_update_menu(PlacesView *pd)
     }
 
     /* "Search for Files" or "Recent Documents" -> separator */
-#if USE_RECENT_DOCUMENTS
     if(pd->cfg->show_recent || (pd->cfg->search_cmd != NULL && *pd->cfg->search_cmd != '\0')){
-#else
-    if(pd->cfg->search_cmd != NULL && *pd->cfg->search_cmd != '\0'){
-#endif
         separator = gtk_separator_menu_item_new();
         gtk_menu_shell_append(GTK_MENU_SHELL(pd->menu), separator);
         gtk_widget_show(separator);
@@ -651,45 +652,49 @@ pview_update_menu(PlacesView *pd)
     /* Search for files */
     if(pd->cfg->search_cmd != NULL && *pd->cfg->search_cmd != '\0'){
 
+        G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         GtkWidget *search_item = gtk_image_menu_item_new_with_mnemonic(_("Search for Files"));
-        
+        G_GNUC_END_IGNORE_DEPRECATIONS
+
         if(pd->cfg->show_icons){
+            G_GNUC_BEGIN_IGNORE_DEPRECATIONS
             GtkWidget *search_image = gtk_image_new_from_icon_name("system-search", GTK_ICON_SIZE_MENU);
             gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(search_item), search_image);
+            G_GNUC_END_IGNORE_DEPRECATIONS
         }
-        
+
         gtk_menu_shell_append(GTK_MENU_SHELL(pd->menu), search_item);
         gtk_widget_show(search_item);
-        
+
         g_signal_connect_swapped(search_item, "activate",
                                  G_CALLBACK(places_gui_exec), pd->cfg->search_cmd);
 
     }
 
     /* Recent Documents */
-#if USE_RECENT_DOCUMENTS
     if(pd->cfg->show_recent){
 
         recent_menu = gtk_recent_chooser_menu_new();
 
         gtk_recent_chooser_set_show_icons(GTK_RECENT_CHOOSER(recent_menu), pd->cfg->show_icons);
         gtk_recent_chooser_set_limit(GTK_RECENT_CHOOSER(recent_menu), pd->cfg->show_recent_number);
+        gtk_recent_chooser_set_sort_type(GTK_RECENT_CHOOSER(recent_menu), GTK_RECENT_SORT_MRU);
 
-        g_signal_connect(recent_menu, "item-activated", 
+        g_signal_connect(recent_menu, "item-activated",
                          G_CALLBACK(pview_cb_recent_item_open), pd);
-            
+
         if(pd->cfg->show_recent_clear){
 
             separator = gtk_separator_menu_item_new();
             gtk_menu_shell_append(GTK_MENU_SHELL(recent_menu), separator);
             gtk_widget_show(separator);
-   
+
             if(pd->cfg->show_icons){
+                G_GNUC_BEGIN_IGNORE_DEPRECATIONS
                 clear_item = gtk_image_menu_item_new_from_stock(GTK_STOCK_CLEAR, NULL);
+                G_GNUC_END_IGNORE_DEPRECATIONS
             }else{
-                GtkStockItem clear_stock_item;
-                gtk_stock_lookup(GTK_STOCK_CLEAR, &clear_stock_item);
-                clear_item = gtk_menu_item_new_with_mnemonic(clear_stock_item.label);
+                clear_item = gtk_menu_item_new_with_mnemonic(_("_Clear"));
             }
 
             gtk_menu_shell_append(GTK_MENU_SHELL(recent_menu), clear_item);
@@ -701,18 +706,20 @@ pview_update_menu(PlacesView *pd)
             /* use activate when button-release-event doesn't catch it (e.g., enter key pressed) */
             g_signal_connect(clear_item, "activate",
                              G_CALLBACK(pview_cb_recent_items_clear), recent_menu);
-    
+
         }
-    
+
+        G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         recent_item = gtk_image_menu_item_new_with_label(_("Recent Documents"));
         if(pd->cfg->show_icons){
-            gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(recent_item), 
+            gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(recent_item),
                                           gtk_image_new_from_stock(GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU));
         }
-        
+        G_GNUC_END_IGNORE_DEPRECATIONS
+
         gtk_menu_item_set_submenu(GTK_MENU_ITEM(recent_item), recent_menu);
         gtk_widget_show(recent_menu);
-        
+
         gtk_menu_shell_append(GTK_MENU_SHELL(pd->menu), recent_item);
         gtk_widget_show(recent_item);
 
@@ -720,7 +727,6 @@ pview_update_menu(PlacesView *pd)
                                                               G_CALLBACK(pview_cb_recent_changed), recent_menu);
         pview_cb_recent_changed(recent_manager, recent_menu);
     }
-#endif
 
     /* connect deactivate signal */
     g_signal_connect_swapped(pd->menu, "deactivate",
@@ -734,7 +740,8 @@ pview_update_menu(PlacesView *pd)
 }
 
 static void
-pview_open_menu(PlacesView *pd)
+pview_open_menu_at (PlacesView   *pd,
+                    GtkWidget    *button)
 {
     /* check if menu is needed, or it needs an update */
     if(pd->menu == NULL || pview_model_changed(pd->bookmark_groups))
@@ -744,28 +751,30 @@ pview_open_menu(PlacesView *pd)
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pd->button), TRUE);
 
     /* popup menu */
-    gtk_menu_popup (GTK_MENU (pd->menu), NULL, NULL,
-                    xfce_panel_plugin_position_menu,
-                    pd->plugin, 0,
-                    gtk_get_current_event_time ());
-    
+    DBG("menu: %lu", (gulong)pd->menu);
+    if (button == NULL)
+        open_menu_at_pointer (GTK_MENU (pd->menu));
+    else
+        open_menu_at_widget (GTK_MENU (pd->menu), button);
+
     /* menu timeout to poll for model changes */
     if(pd->menu_timeout_id == 0){
-#if GLIB_CHECK_VERSION(2,14,0)
-        pd->menu_timeout_id = g_timeout_add_seconds_full(G_PRIORITY_LOW, 2, 
+        pd->menu_timeout_id = g_timeout_add_seconds_full(G_PRIORITY_LOW, 2,
                                    (GSourceFunc) pview_cb_menu_timeout, pd,
                                    NULL);
-#else
-        pd->menu_timeout_id = g_timeout_add_full(G_PRIORITY_LOW, 2000, 
-                                   (GSourceFunc) pview_cb_menu_timeout, pd,
-                                   NULL);
-#endif
         PLACES_DEBUG_MENU_TIMEOUT_COUNT(1);
     }else{
         PLACES_DEBUG_MENU_TIMEOUT_COUNT(0);
     }
 }
 
+static void
+pview_open_menu(PlacesView *pd)
+{
+  if (pd != NULL)
+    pview_open_menu_at (pd, pd->button);
+}
+
 static GdkPixbuf*
 pview_pixbuf_factory(gint size)
 {
@@ -802,96 +811,78 @@ pview_button_update(PlacesView *view)
     /* tooltips */
     new_tooltip_text_hash = g_str_hash(cfg->label);
     if (new_tooltip_text_hash != tooltip_text_hash) {
-
-#if USE_GTK_TOOLTIP_API
         gtk_widget_set_tooltip_text(view->button, cfg->label);
-#else
-        gtk_tooltips_set_tip(view->tooltips, view->button, cfg->label, NULL);
-#endif
-
     }
     tooltip_text_hash = new_tooltip_text_hash;
 
 }
 /********** Handle user message **********/
+
+/* copied from xfce4-panel/common/utils.c (panel_utils_grab_available) */
 static gboolean
-pview_popup_command_message_received(GtkWidget *widget,
-                                     GdkEventClient *ev,
-                                     PlacesView *view)
+pview_grab_available (void)
 {
-    if (G_LIKELY (ev->data_format == 8 && *(ev->data.b) != '\0'
-                  && !g_ascii_strcasecmp (PLACES_MSG_MENU, ev->data.b))){
-        DBG ("Message received: '%s'", ev->data.b);
-
-        pview_open_menu (view);
-        return TRUE;
-    }
-
-    DBG("Bad message received");
-    return FALSE;
+    /* TODO fix for gtk3 */
+    return TRUE;
 }
 
+
 static gboolean
-pview_popup_command_set_selection(PlacesView *view)
+pview_remote_event(XfcePanelPlugin *panel_plugin,
+                   const gchar     *name,
+                   const GValue    *value,
+                   PlacesView      *view)
 {
-    GdkScreen          *gscreen;
-    gchar               selection_name[256];
-    Atom                selection_atom;
-    Window              id;
+  g_return_val_if_fail (value == NULL || G_IS_VALUE (value), FALSE);
 
-    id = GDK_WINDOW_XID (GTK_WIDGET (view->plugin)->window);
+  DBG("remote event: %s, %lu", name, (gulong) view);
 
-    gscreen = gtk_widget_get_screen (GTK_WIDGET(view->plugin));
+  if (strcmp (name, "popup") == 0
+      && gtk_widget_is_visible (GTK_WIDGET (panel_plugin))
+      && !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (view->button))
+      && pview_grab_available ()) /* checking if there is another menu on the screen */
+    {
+      if (value != NULL
+          && G_VALUE_HOLDS_BOOLEAN (value)
+          && g_value_get_boolean (value))
+        {
+          /* popup the menu under the pointer */
+          pview_open_menu_at (view, NULL);
+        }
+      else
+        {
+          /* show the menu */
+          pview_open_menu(view);
+        }
+      /* don't popup another menu */
+      return TRUE;
+    }
 
-    g_snprintf (selection_name, 256,
-                XFCE_PLACES_SELECTION"%d",
-                gdk_screen_get_number (gscreen));
-    
-    selection_atom = XInternAtom (GDK_DISPLAY (), selection_name, FALSE);
-
-    if (XGetSelectionOwner (GDK_DISPLAY (), selection_atom))
-        return FALSE;
-
-    XSetSelectionOwner (GDK_DISPLAY (), selection_atom, id, GDK_CURRENT_TIME);
-
-    g_signal_connect (GTK_WIDGET(view->plugin),
-                      "client-event",
-                      G_CALLBACK (pview_popup_command_message_received),
-                      view);
-
-    return TRUE;
+  return FALSE;
 }
 
 /********** Initialization & Finalization **********/
 PlacesView*
 places_view_init(XfcePanelPlugin *plugin)
 {
-    PlacesView *view;                   /* internal use in this file */
-    PlacesViewCfgIface *view_cfg_iface; /* given to cfg */
+    PlacesView   *view;                   /* internal use in this file */
+    GtkIconTheme *icon_theme;
 
     DBG("initializing");
     g_assert(plugin != NULL);
 
     view            = g_new0(PlacesView, 1);
     view->plugin    = plugin;
-    
-    view_cfg_iface                          = g_new0(PlacesViewCfgIface, 1);
-    view_cfg_iface->places_view             = view;
-    view_cfg_iface->update_menu             = pview_update_menu;
-    view_cfg_iface->update_button           = pview_button_update;
-    view_cfg_iface->reconfigure_model       = pview_reconfigure_model;
-    view->view_cfg_iface = view_cfg_iface;
 
-    view->cfg      = places_cfg_new(view->plugin, view_cfg_iface);
+    view->cfg      = places_cfg_new(view->plugin);
+    g_signal_connect_swapped (G_OBJECT (view->cfg), "button-changed",
+                              G_CALLBACK (pview_button_update), view);
+    g_signal_connect_swapped (G_OBJECT (view->cfg), "menu-changed",
+                              G_CALLBACK (pview_update_menu), view);
+    g_signal_connect_swapped (G_OBJECT (view->cfg), "model-changed",
+                              G_CALLBACK (pview_reconfigure_model), view);
 
     pview_reconfigure_model(view);
-    
-#if USE_GTK_TOOLTIP_API
-    DBG("using GtkTooltip API");
-#else
-    DBG("using GtkTooltips API");
-    view->tooltips = exo_gtk_object_ref_sink(GTK_OBJECT(gtk_tooltips_new()));
-#endif
 
     /* init button */
 
@@ -905,27 +896,28 @@ places_view_init(XfcePanelPlugin *plugin)
 
     pview_button_update(view);
 
+
     /* signals for icon theme/screen changes */
-    g_signal_connect_swapped(view->button, "style-set",
-                             G_CALLBACK(pview_destroy_menu), view);
+    icon_theme = gtk_icon_theme_get_default ();
+    g_signal_connect_swapped (icon_theme, "changed",
+                              G_CALLBACK(pview_destroy_menu), view);
     g_signal_connect_swapped(view->button, "screen-changed",
                              G_CALLBACK(pview_destroy_menu), view);
-    
+
     /* button signal */
     g_signal_connect_swapped(view->button, "button-press-event",
                              G_CALLBACK(pview_cb_button_pressed), view);
 
-
-
-    /* set selection for xfce4-popup-places */
-    pview_popup_command_set_selection(view);
+    /* remote control signal */
+    g_signal_connect(G_OBJECT(view->plugin), "remote-event",
+                     G_CALLBACK(pview_remote_event), view);
 
     DBG("done");
 
     return view;
 }
 
-void 
+void
 places_view_finalize(PlacesView *view)
 {
     pview_destroy_menu(view);
@@ -942,17 +934,9 @@ places_view_finalize(PlacesView *view)
         view->button = NULL;
     }
 
-#if !USE_GTK_TOOLTIP_API
-    g_object_unref(view->tooltips);
-    view->tooltips = NULL;
-#endif
-
-    places_cfg_finalize(view->cfg);
+    g_object_unref(view->cfg);
     view->cfg = NULL;
 
-    g_free(view->view_cfg_iface);
-    view->view_cfg_iface = NULL;
-
     g_free(view);
 
 #ifdef HAVE_LIBNOTIFY
